# ifndef yyMakeOvUpdates
# define yyMakeOvUpdates

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"


extern void (* MakeOvUpdates_Exit) ARGS ((void));

extern void MakeOvUpdates ARGS ((tTree t));

extern void BeginMakeOvUpdates ARGS ((void));
extern void CloseMakeOvUpdates ARGS ((void));

# endif
